audio_volume {#master}
-------------------------

## Important Changes

### Libraries

#### yarp::sig
* `yarp::sig::sound` added the following methods:  amplifyChannel(), amplify(), findPeakInChannel(), findPeak(), normalizeChannel(), normalize() 
* `harness_sig`: added tests to check the new methods

#### yarp::dev
* Added the new datatypes `yarp::dev::audioRecorderStatus` and `yarp::dev::audioPlaybackStatus` generated by thrift.
* Added the new class `AudioPlayerDeviceBase`, all playback device drivers now derive from this class.
* Added the new class `AudioRecorerDeviceBase`, all recording device drivers now derive from this class.
* Added the new methods to `setHWGain()`, `setSWGain()` to `IAudioRender` interface.
* Added the new methods to `setHWGain()`, `setSWGain()` to `IAudioGrabberSound` interface.

### Devices
* Added RPC commands to `AudioPlayerWrapper` and `AudioRecorderWrapper`, to control the volume via setHWGain()`, `setSWGain()`
* `AudioPlayerWrapper` and `AudioRecorderWrapper` now broadcast their internal status on a xxx/status:o port
* All playback device drivers, i.e. `audioToFileDevice`, `fakeSpeaker`, `portaudioPlayer` ,now derive from `AudioPlayerDeviceBase`.
* All recording device drivers, i.e. `audioFromFileDevice`,`fakeMicrophone`,`portaadioRecorder`, now derive from `AudioRecorderDeviceBase`.

